require 'spec_helper'

describe PurolatorRuby::Client do

  class TestCredentials
    def wsdl_location
      File.expand_path('spec/support/ShippingService.wsdl')
    end

    def soap_header
      {'Request' => 'Header'}
    end

    def soap_header_v13
      soap_header
    end

    def soap_header_v15
      soap_header
    end

    def basic_auth
      ['FOO', 'BAR']
    end

    def account_number
      1
    end

    def billing_number
      2
    end
  end

  subject { build_client }

  it "uses account_number and billing_number from credentials" do
    expect(subject.account_number).to eq(1)
    expect(subject.billing_number).to eq(2)
  end

  context "call method" do
    let(:resp) { double(body: {}) }
    let(:savon) { double(call: resp) }

    before do
      expect(Savon).to receive(:client).and_return(savon)

      expect(PurolatorRuby::CreateShipmentPayload).to receive(:new)
      expect(PurolatorRuby::CreateShipmentResponse).to receive(:new)
    end

    it "has a call method which creates request and response objects" do
      subject.call(:create_shipment, {shipping_date: Date.today})
    end

    it "has a create_shipment method" do
      subject.create_shipment shipping_date: Date.today
    end

  end
  context "wsdl" do

    it "instantiates Savon with WsdlLocation" do
      allow(PurolatorRuby::WsdlLocation).to receive(:new).and_return(double(location_for: '42', soap_header_for: {}))

      expect(Savon).to receive(:client) do |params|
        expect(params[:wsdl]).to eq('42')
      end.and_return(double(call: double(body: {})))

      subject.call(:create_shipment, {shipping_date: Date.today})
    end
  end

  def build_client
    described_class.new(credentials: TestCredentials.new)
  end

end
