require 'spec_helper'

describe PurolatorRuby::CreateShipmentResponse do

  subject { described_class.new(response) }

  context "success" do
    let(:response) do
      {
          :create_shipment_response => {
               :response_information => {
                                  :errors => nil,
                  :informational_messages => nil
              },
                       :shipment_pin => {
                  :value => "329018602212"
              },
                        :piece_pi_ns => {
                  :pin => {
                      :value => "329018602212"
                  }
              },
              :return_shipment_pi_ns => nil,
                 :express_cheque_pin => {
                  :value => nil
              },
                             :@xmlns => "http://purolator.com/pws/datatypes/v1",
                         :"@xmlns:i" => "http://www.w3.org/2001/XMLSchema-instance"
          }
      }
    end

    it "has status success" do
      expect(subject.status).to eq(:ok)
    end

    it "has shipment_pin" do
      expect(subject.shipment_pin).to eq("329018602212")
    end

  end

  context "failure" do
    let(:response) do
      {:create_shipment_response=>{:response_information=>{:errors=>{:error=>{:code=>"1100759", :description=>"Invalid Shipment Date: Date must be between Thursday, July 23, 2015 and Sunday, August 2, 2015.", :additional_information=>"Shipping Error"}}, :informational_messages=>nil}, :shipment_pin=>nil, :piece_pi_ns=>nil, :return_shipment_pi_ns=>nil, :express_cheque_pin=>nil, :@xmlns=>"http://purolator.com/pws/datatypes/v1", :"@xmlns:i"=>"http://www.w3.org/2001/XMLSchema-instance"}}
    end

    it "has status error" do
      expect(subject.status).to eq(:error)
    end

    it "has errors" do
      expect(subject.errors).to eq(['Invalid Shipment Date: Date must be between Thursday, July 23, 2015 and Sunday, August 2, 2015.'])
    end
  end

end
