require 'spec_helper'

describe PurolatorRuby::EnvironmentCredentials do

  let(:wsdl_location) { File.expand_path('spec/support/ShippingService.wsdl') }
  let(:developer_key) { 'foo' }
  let(:developer_password) { 'bar' }
  let(:client_id) { '42' }
  let(:billing_number) { '123' }
  let(:account_number) { '953' }

  before do
    ENV['PLUROLATOR_RUBY_WSDL_LOCATION'] = wsdl_location
    ENV['PLUROLATOR_RUBY_DEVELOPER_KEY'] = developer_key
    ENV['PLUROLATOR_RUBY_DEVELOPER_PASSWORD'] = developer_password
    ENV['PLUROLATOR_RUBY_CLIENT_ID'] = client_id
    ENV['PLUROLATOR_RUBY_BILLING_NUMBER'] = billing_number
    ENV['PLUROLATOR_RUBY_ACCOUNT_NUMBER'] = account_number
  end

  subject { described_class.new }

  it "has valid basic_auth pair" do
    expect(subject.basic_auth).to eq([developer_key, developer_password])
  end

  it "has a soap_header with client_id" do
    expect(subject.soap_header).to eq({'ns1:RequestContext' =>
          {'ns1:Version' => '1.5',
            'ns1:Language' => 'en',
            'ns1:GroupID' => 'xxx',
            'ns1:RequestReference' => 'Rating Example',
            'ns1:UserToken' => client_id}
        })
  end

  it "has account and billing numbers" do
    expect(subject.account_number).to eq(account_number)
    expect(subject.billing_number).to eq(billing_number)
  end
end
