require 'spec_helper'

describe "Integration create shipment" do

  before { setup_env }

  let(:client) { PurolatorRuby::Client.new }

  context "valid payload" do

    let(:payload) do
      {
        sender_address: sender_address,
        receiver_address: receiver_address,
        shipping_date: Date.today,
        weight: '10',
        pieces: 1,
        reference: 'ref 45'
      }
    end

    it "succesfully communicates with ShippingService and returns shipment pin" do
      VCR.use_cassette('shipping_service_integration') do
        response = client.call(:create_shipment, payload)
        expect(response.shipment_pin).to eq('329018602238')
        expect(response.status).to eq(:ok)
      end
    end

  end

  context "invalid payload" do
    let(:payload) do
      {
        sender_address: sender_address,
        receiver_address: receiver_address,
        shipping_date: Date.new(2014, 01, 01),
        weight: '10',
        pieces: 1,
        reference: '12'
      }
    end


    it "has status error" do
      VCR.use_cassette('shipping_service_integration_2') do
        response = client.call(:create_shipment, payload)
        expect(response.status).to eq(:error)
      end
    end
  end

end
