require 'spec_helper'

describe PurolatorRuby::WsdlLocation do

  let(:test_root) { File.expand_path(File.join(File.dirname(__FILE__), '..')) }
  let(:credentials) { double(wsdl_location: test_root, soap_header_v15: 'v15', soap_header_v13: 'v13') }

  subject { described_class.new(credentials: credentials) }

  it "can tell location for wsdl based on method" do
    expect(subject.location_for(:create_shipment))
      .to eq(File.join(test_root, 'ShippingService.wsdl'))
  end

  it "can tell location for validation service" do
    expect(subject.location_for(:validate_city_postal_code_zip))
      .to eq(File.join(test_root, 'ServiceAvailabilityService.wsdl'))
  end

  it "can tell soap_header for create shipment" do
    expect(subject.soap_header_for(:create_shipment)).to eq('v15')
  end

  it "can tell soap_header for validation service" do
    expect(subject.soap_header_for(:validate_city_postal_code_zip)).to eq('v13')
  end

  it "can tell location for get_documents service" do
    expect(subject.location_for(:get_documents))
      .to eq(File.join(test_root, 'ShippingDocumentsService.wsdl'))
  end

  it "can tell soap_header for get_documents service" do
    expect(subject.soap_header_for(:get_documents)).to eq('v13')
  end

end
