require 'spec_helper'

describe PurolatorRuby::CreateShipmentPayload do

  let(:shipping_date) { Date.today }
  let(:weight) { '14' }
  let(:pieces) { '2' }
  let(:reference) { 'Ref #3456' }
  let(:billing_number) { '432' }
  let(:account_number) { '8721' }

  subject do
    described_class.new(
      sender_address: sender_address,
      receiver_address: receiver_address,
      shipping_date: shipping_date,
      weight: weight,
      pieces: pieces,
      reference: reference,
      billing_number: billing_number,
      account_number: account_number)
  end

  it "creates a valid SOAP payload" do
    expect(subject.to_h).to eq(
      {"Shipment"=>{
        "SenderInformation"=>sender_address,
        "ReceiverInformation"=>receiver_address,
        "ShipmentDate"=>shipping_date.strftime('%Y-%m-%d'),
        "PackageInformation"=>{
          "ServiceID"=>"PurolatorExpress",
          "TotalWeight"=>{"Value"=>weight, "WeightUnit"=>"lb"},
          "TotalPieces"=>pieces,
          "OptionsInformation"=>{
            "Options"=>{"OptionIDValuePair"=>{"ID"=>"ResidentialSignatureDomestic", "Value"=>"true"}}}},
        "PaymentInformation"=>{"PaymentType"=>"Sender", "RegisteredAccountNumber"=>account_number, "BillingAccountNumber"=>billing_number},
        "PickupInformation"=>{"PickupType"=>"DropOff"},
        "TrackingReferenceInformation"=>{"Reference1"=>reference}}, "PrinterType"=>"Thermal"})
  end

end
